@@ -718,6 +718,15 @@ test_parsing_content_type (void)
 	g_free (uri);
 }
 
+static void
+test_parsing_medium (void)
+{
+	char *uri;
+	uri = get_relative_uri (TEST_SRCDIR "791154-kqed.rss");
+	g_assert_cmpstr (parser_test_get_entry_field (uri, TOTEM_PL_PARSER_FIELD_URI), ==, "https://www.podtrac.com/pts/redirect.mp3/www.kqed.org/.stream/anon/radio/tcrmag/2017/12/TCRPodcastDec1.mp3");
+	g_free (uri);
+}
+
 static void
 test_parsing_hadess (void)
 {
@@ -1299,6 +1308,7 @@ main (int argc, char *argv[])
 		g_test_add_func ("/parser/parsing/multi_line_rtsptext", test_parsing_rtsp_text_multi);
 		g_test_add_func ("/parser/parsing/single_line_rtsptext", test_parsing_rtsp_text);
 		g_test_add_func ("/parser/parsing/podcast_content_type", test_parsing_content_type);
+		g_test_add_func ("/parser/parsing/podcast_medium", test_parsing_medium);
 		g_test_add_func ("/parser/parsing/live_streaming", test_parsing_live_streaming);
 		g_test_add_func ("/parser/parsing/xml_mixed_cdata", test_parsing_xml_mixed_cdata);
 		g_test_add_func ("/parser/parsing/m3u_streaming", test_parsing_m3u_streaming);
