@@ -1742,6 +1742,7 @@ totem_pl_parser_ignore_from_mimetype (TotemPlParser *parser, const char *mimetyp
 		 * in shared-mime-info */
 		if (strcmp (mimetype, "application/vnd.apple.mpegurl") != 0 &&
 		    strcmp (mimetype, "audio/x-mpegurl") != 0 &&
+		    strcmp (mimetype, "video/x-mjpeg") != 0 &&
 		    g_content_type_is_a (mimetype, ignore_types[i].mimetype) != FALSE) {
 			if (parser->priv->debug)
 				g_print ("Ignoring %s because it's a %s\n", mimetype, ignore_types[i].mimetype);
@@ -1828,8 +1829,10 @@ totem_pl_parser_parse_internal (TotemPlParser *parser,
 		url = g_file_get_uri (file);
 		if (url != NULL && totem_pl_parser_is_videosite (url, parser->priv->debug) != FALSE) {
 			ret = totem_pl_parser_add_videosite (parser, file, base_file, parse_data, NULL);
-			if (ret == TOTEM_PL_PARSER_RESULT_SUCCESS)
+			if (ret == TOTEM_PL_PARSER_RESULT_SUCCESS) {
+				g_free (url);
 				return ret;
+			}
 		}
 		g_free (url);
 	}
